@@ -540,7 +540,6 @@ int Fl_WinAPI_Screen_Driver::ready() {
   return get_wsock_mod() ? s_wsock_select(0, &fdt[0], &fdt[1], &fdt[2], &t) : 0;
 }
 
-//FILE *LOG=fopen("log.log","w");
 
 void Fl_WinAPI_Screen_Driver::open_display_platform() {
   static char beenHereDoneThat = 0;
@@ -549,21 +548,37 @@ void Fl_WinAPI_Screen_Driver::open_display_platform() {
     return;
 
   beenHereDoneThat = 1;
-  typedef void *fl_DPI_AWARENESS_CONTEXT;
-  typedef BOOL(WINAPI * SetProcessDpiAwarenessContext_type)(fl_DPI_AWARENESS_CONTEXT);
-  SetProcessDpiAwarenessContext_type fl_SetProcessDpiAwarenessContext =
-      (SetProcessDpiAwarenessContext_type)GetProcAddress(LoadLibrary("User32.DLL"), "SetProcessDpiAwarenessContext");
-  if (fl_SetProcessDpiAwarenessContext) {
-    const fl_DPI_AWARENESS_CONTEXT fl_DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE_V2 = (fl_DPI_AWARENESS_CONTEXT)(-4);
-    is_dpi_aware = fl_SetProcessDpiAwarenessContext(fl_DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE_V2);
+  // test whether DpiAwareness has been set before via a manifest
+  /*enum PROCESS_DPI_AWARENESS { // in shellscalingapi.h from Window 8.1
+    PROCESS_DPI_UNAWARE,
+    PROCESS_SYSTEM_DPI_AWARE,
+    PROCESS_PER_MONITOR_DPI_AWARE
+  };*/
+  typedef HRESULT(WINAPI * GetProcessDpiAwareness_type)(HANDLE, int *);
+  GetProcessDpiAwareness_type fl_GetProcessDpiAwareness =
+      (GetProcessDpiAwareness_type)GetProcAddress(LoadLibrary("Shcore.DLL"), "GetProcessDpiAwareness");
+  int awareness;
+  if (!fl_GetProcessDpiAwareness || fl_GetProcessDpiAwareness(NULL, &awareness) != S_OK) {
+    awareness = 0; //corresponds to PROCESS_DPI_UNAWARE;
   }
-  if (!is_dpi_aware) {
-    typedef HRESULT(WINAPI * SetProcessDpiAwareness_type)(int);
-    SetProcessDpiAwareness_type fl_SetProcessDpiAwareness =
-        (SetProcessDpiAwareness_type)GetProcAddress(LoadLibrary("Shcore.DLL"), "SetProcessDpiAwareness");
-    if (fl_SetProcessDpiAwareness) {
-      const int fl_PROCESS_PER_MONITOR_DPI_AWARE = 2;
-      if (fl_SetProcessDpiAwareness(fl_PROCESS_PER_MONITOR_DPI_AWARE) == S_OK) is_dpi_aware = true;
+  if (awareness == 2 /*PROCESS_PER_MONITOR_DPI_AWARE*/) is_dpi_aware = true;
+  if (awareness == 0 /*PROCESS_DPI_UNAWARE*/) { // DpiAwareness has not been set via a manifest
+    typedef void *fl_DPI_AWARENESS_CONTEXT;
+    typedef BOOL(WINAPI * SetProcessDpiAwarenessContext_type)(fl_DPI_AWARENESS_CONTEXT);
+    SetProcessDpiAwarenessContext_type fl_SetProcessDpiAwarenessContext =
+    (SetProcessDpiAwarenessContext_type)GetProcAddress(LoadLibrary("User32.DLL"), "SetProcessDpiAwarenessContext");
+    if (fl_SetProcessDpiAwarenessContext) {
+      const fl_DPI_AWARENESS_CONTEXT fl_DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE_V2 = (fl_DPI_AWARENESS_CONTEXT)(-4);
+      is_dpi_aware = fl_SetProcessDpiAwarenessContext(fl_DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE_V2);
+    }
+    if (!is_dpi_aware) {
+      typedef HRESULT(WINAPI * SetProcessDpiAwareness_type)(int);
+      SetProcessDpiAwareness_type fl_SetProcessDpiAwareness =
+      (SetProcessDpiAwareness_type)GetProcAddress(LoadLibrary("Shcore.DLL"), "SetProcessDpiAwareness");
+      if (fl_SetProcessDpiAwareness) {
+        const int fl_PROCESS_PER_MONITOR_DPI_AWARE = 2;
+        if (fl_SetProcessDpiAwareness(fl_PROCESS_PER_MONITOR_DPI_AWARE) == S_OK) is_dpi_aware = true;
+      }
     }
   }
   OleInitialize(0L);
@@ -1763,7 +1778,7 @@ static int fake_X_wm_style(const Fl_Window *w, int &X, int &Y, int &bt, int &bx,
       static AdjustWindowRectExForDpi_type fl_AdjustWindowRectExForDpi =
         (AdjustWindowRectExForDpi_type)GetProcAddress(LoadLibrary("User32.DLL"), "AdjustWindowRectExForDpi");
       BOOL ok;
-      if ( fl_AdjustWindowRectExForDpi) {
+      if (is_dpi_aware && fl_AdjustWindowRectExForDpi) {
         Fl_WinAPI_Screen_Driver *sd = (Fl_WinAPI_Screen_Driver*)Fl::screen_driver();
         UINT dpi = UINT(sd->dpi[Fl_Window_Driver::driver(w)->screen_num()][0]);
         ok = fl_AdjustWindowRectExForDpi(&r, style, FALSE, styleEx, dpi);
@@ -2069,14 +2084,12 @@ Fl_X *Fl_WinAPI_Window_Driver::makeWindow() {
   } else {
     if (!size_range_set()) {
       if (w->resizable()) {
-        Fl_Widget *o = w->resizable();
-        int minw = o->w();
-        if (minw > 100)
-          minw = 100;
-        int minh = o->h();
-        if (minh > 100)
-          minh = 100;
-        w->size_range(w->w() - o->w() + minw, w->h() - o->h() + minh, 0, 0);
+       Fl_Widget *o = w->resizable();
+       int minw = w->w();                     // minw is window's initial width
+       int minh = w->h();                     // minh is window's initial height
+       int maxw = (o->w() == 0) ? minw : 0;   // if resizable w()==0, disable resize w()
+       int maxh = (o->h() == 0) ? minh : 0;   // if resizable h()==0, disable resize h()
+       w->size_range(minw, minh, maxw, maxh);
       } else {
         w->size_range(w->w(), w->h(), w->w(), w->h());
       }
@@ -2671,7 +2684,7 @@ void fl_free_fonts(void) {
     s = fl_fonts + i;
     for (f = s->first; f; f = ff) {
       ff = f->next;
-      delete f;
+      delete (Fl_GDI_Font_Descriptor*)f;
       s->first = ff;
     }
   }
