@@ -60,6 +60,16 @@ void Fl_Window_show_with_args(Fl_Window *w, int argc, char **argv);
 
 void Fl_Window_set_raw_handle(Fl_Window *self, void *handle);
 
+const char *Fl_Window_default_xclass(void);
+
+const char *Fl_Window_xclass(const Fl_Window *self);
+
+void Fl_Window_set_default_xclass(const char *s);
+
+void Fl_Window_set_xclass(Fl_Window *self, const char *s);
+
+void Fl_Window_clear_modal_states(Fl_Window *self);
+
 WIDGET_DECLARE(Fl_Single_Window)
 
 GROUP_DECLARE(Fl_Single_Window)
@@ -74,6 +84,8 @@ void Fl_Double_Window_set_alpha(Fl_Double_Window *self, unsigned char val);
 
 unsigned char Fl_Double_Window_alpha(const Fl_Double_Window *self);
 
+void Fl_Double_Window_force_position(Fl_Double_Window *self, int flag);
+
 GROUP_DECLARE(Fl_Double_Window)
 
 WINDOW_DECLARE(Fl_Double_Window)
