@@ -4,7 +4,7 @@
 #include <windows.h>
 #endif
 #elif __APPLE__
-extern "C" void setWindowTransparency(void *, unsigned char);
+extern "C" void cfltk_setWindowTransparency(void *, unsigned char);
 #elif __ANDROID__
 #else
 #include <X11/Xatom.h>
@@ -200,6 +200,27 @@ void Fl_Window_set_raw_handle(Fl_Window *self, void *handle) {
 #endif
 }
 
+const char *Fl_Window_default_xclass(void) {
+    LOCK(auto ret = Fl_Window::default_xclass());
+    return ret;
+}
+
+const char *Fl_Window_xclass(const Fl_Window *self) {
+    LOCK(return self->xclass());
+}
+
+void Fl_Window_set_default_xclass(const char *s) {
+    LOCK(Fl_Window::default_xclass(s));
+}
+
+void Fl_Window_set_xclass(Fl_Window *self, const char *s) {
+    LOCK(self->xclass(s));
+}
+
+void Fl_Window_clear_modal_states(Fl_Window *self) {
+    LOCK(self->clear_modal_states());
+}
+
 WIDGET_CLASS(Fl_Single_Window)
 
 WIDGET_DEFINE(Fl_Single_Window)
@@ -245,7 +266,7 @@ struct Fl_Double_Window_Derived : public Fl_Double_Window {
         }
         SetLayeredWindowAttributes(hwnd, 0, BYTE(alpha), LWA_ALPHA);
 #elif defined(__APPLE__)
-        setWindowTransparency((void *)fl_xid(this), alpha); // definition in separate .m file
+        cfltk_setWindowTransparency((void *)fl_xid(this), alpha); // definition in separate .m file
 #elif defined(__ANDROID__)
         // Do nothing
 #else
@@ -316,6 +337,10 @@ struct Fl_Double_Window_Derived : public Fl_Double_Window {
         }
     }
 
+    void force_pos(int flag) {
+        force_position(flag);
+    }
+
     ~Fl_Double_Window_Derived() {
         if (ev_data_)
             deleter(ev_data_);
@@ -350,6 +375,10 @@ unsigned char Fl_Double_Window_alpha(const Fl_Double_Window *self) {
     return ret;
 }
 
+void Fl_Double_Window_force_position(Fl_Double_Window *self, int flag) {
+    LOCK(((Fl_Double_Window_Derived *)self)->force_pos(flag));
+}
+
 GROUP_DEFINE(Fl_Double_Window)
 
 WINDOW_DEFINE(Fl_Double_Window)
